@@ -27,11 +27,13 @@ from .raw import transform as raw_transform
 from .short import transform as short_transform
 from .slick import transform as slick_transform
 from .classic import transform as classic_transform
+from .fails import transform as fails_transform
 from .read_and_filter import transform as read_and_filter_transform
 from .report.passing import transform as passing_report_transform
 from .report.fails import transform as fails_report_transform
 from .report.totals import transform as totals_report_transform
 from .report.version import transform as version_report_transform
+from .report.coverage import transform as coverage_report_transform
 from .report.metrics import transform as metrics_transform
 from .report.results import transform as results_transform
 
@@ -120,6 +122,7 @@ class ShortLogPipeline(Pipeline):
                 short_transform(),
                 passing_report_transform(stop_event),
                 fails_report_transform(stop_event),
+                coverage_report_transform(stop_event),
                 totals_report_transform(stop_event),
                 version_report_transform(stop_event),
             ),
@@ -142,6 +145,7 @@ class NiceLogPipeline(Pipeline):
                 nice_transform(),
                 passing_report_transform(stop_event),
                 fails_report_transform(stop_event),
+                coverage_report_transform(stop_event),
                 totals_report_transform(stop_event),
                 version_report_transform(stop_event),
             ),
@@ -164,6 +168,7 @@ class SlickLogPipeline(Pipeline):
                 slick_transform(),
                 passing_report_transform(stop_event),
                 fails_report_transform(stop_event),
+                coverage_report_transform(stop_event),
                 totals_report_transform(stop_event),
                 version_report_transform(stop_event),
             ),
@@ -186,6 +191,7 @@ class ClassicLogPipeline(Pipeline):
                 classic_transform(),
                 passing_report_transform(stop_event),
                 fails_report_transform(stop_event),
+                coverage_report_transform(stop_event),
                 totals_report_transform(stop_event),
                 version_report_transform(stop_event),
             ),
@@ -197,6 +203,28 @@ class ClassicLogPipeline(Pipeline):
         ]
         super(ClassicLogPipeline, self).__init__(steps)
 
+class FailsLogPipeline(Pipeline):
+    def __init__(self, input, output, tail=False, only_new=False):
+        stop_event = threading.Event()
+
+        steps = [
+            read_transform(input, tail=tail, stop=stop_event),
+            parse_transform(stop_event),
+            fanout(
+                fails_transform(only_new=only_new),
+                fails_report_transform(stop_event, only_new=only_new),
+                coverage_report_transform(stop_event),
+                totals_report_transform(stop_event),
+                version_report_transform(stop_event),
+            ),
+            fanin(
+                "".join
+            ),
+            write_transform(output),
+            stop_transform(stop_event)
+        ]
+        super(FailsLogPipeline, self).__init__(steps)
+
 class DotsLogPipeline(Pipeline):
     def __init__(self, input, output, tail=False):
         stop_event = threading.Event()
@@ -208,6 +236,7 @@ class DotsLogPipeline(Pipeline):
                 dots_transform(stop_event),
                 passing_report_transform(stop_event),
                 fails_report_transform(stop_event),
+                coverage_report_transform(stop_event),
                 totals_report_transform(stop_event),
                 version_report_transform(stop_event),
             ),
@@ -249,6 +278,7 @@ class ResultsReportLogPipeline(Pipeline):
             fanout(
                 passing_report_transform(stop_event),
                 fails_report_transform(stop_event),
+                coverage_report_transform(stop_event),
                 totals_report_transform(stop_event),
                 version_report_transform(stop_event)
             ),
@@ -325,6 +355,28 @@ class PassingReportLogPipeline(Pipeline):
         ]
         super(PassingReportLogPipeline, self).__init__(steps)
 
+class CoverageReportLogPipeline(Pipeline):
+    def __init__(self, input, output):
+        stop_event = threading.Event()
+
+        message_types = [Message.TEST.name, Message.RESULT.name, Message.REQUIREMENT.name, Message.SPECIFICATION.name, Message.STOP.name]
+        grep = "grep -E '^{\"message_keyword\":\""
+        command = f"{grep}({'|'.join(message_types)})\"'"
+
+        steps = [
+            read_and_filter_transform(input, command=command, stop=stop_event),
+            parse_transform(),
+            fanout(
+                coverage_report_transform(stop_event, divider=""),
+            ),
+            fanin(
+                "".join
+            ),
+            write_transform(output),
+            stop_transform(stop_event)
+        ]
+        super(CoverageReportLogPipeline, self).__init__(steps)
+
 class VersionReportLogPipeline(Pipeline):
     def __init__(self, input, output):
         stop_event = threading.Event()
